function HtmlGraph(elem)
{
    var graph = document.createElement('div');
    graph.style.cssText = 'position:relative;';

    var vertexCounter = 0;
    var edgeCounter = 0;

    var vertices = [];
    this.vertices = vertices;
    var edges = [];
    this.edges = edges;

    function Vertex(type, label)
    {
        this.id = '__vertex__' + ++vertexCounter;
        this.type = type;
        this.label = label;
        this.topPos = 0;
        this.leftPos = 0;
        var self = this;
        function draw()
        {
            var div = document.createElement('div');
            div.className = 'vertex ' + this.type;
            div.style.cssText = 'position:absolute;background:red;border-radius:20px;color:white;padding:5px;font-family:sans-serif;z-index:999;';
            div.appendChild(document.createTextNode(this.label));
            div.style.top = Math.random() * elem.offsetHeight + 'px';
            div.style.left = Math.random() * elem.offsetWidth + 'px';
            self.elem = div;
            return div;
        }
        this.draw = draw;
        draw();
    }

    function Edge(type, fromId, toId)
    {
        this.id = '__edge__' + ++edgeCounter;
        this.type = type;
        function draw()
        {
            var v1 = vertices[fromId];
            var v2 = vertices[toId];
            var x1 = v1.elem.offsetLeft;
            var y1 = v1.elem.offsetTop;
            var x2 = v2.elem.offsetLeft;
            var y2 = v2.elem.offsetTop;

            var h1 = v1.elem.offsetHeight;
            var w1 = v1.elem.offsetWidth;

            var h2 = v2.elem.offsetHeight;
            var w2 = v2.elem.offsetWidth;

            var line;
            if (x1 < x2)
            {
                console.log(x1, y1, x2, y2);
                line = drawLine(x1+w1/2, y1+h1/2, x2+w2/2, y2+h2/2);
            }
            else
            {
                console.log(x2, y2, x1, y1);
                line = drawLine(x2+w2/2, y2+h2/2, x1+w1/2, y1+h1/2);
            }

            line.appendChild(document.createTextNode(type));
            return line;
        }
        this.draw = draw;       
    }

    function addVertex(value, label)
    {
        var v = new Vertex(value, label);
        vertices.push(v);
        vertices[v.id] = v; 
    }
    this.addVertex = addVertex;

    function addEdge(type, fromId, toId)
    {
        edges.push(new Edge(type, fromId, toId));
    }
    this.addEdge = addEdge;


function drawLine(x1, y1, x2, y2)
{
//   var points = line.getAttribute('points');
//   points = points.split(',');
//   var x1 = points[0];
//   var y1 = points[1];
//   var x2 = points[2];
//   var y2 = points[3];
  var line = document.createElement('div');
  line.style.cssText = 'position:absolute;border-top: 1px solid #000;transform-origin:0px !important;text-align:center;';
  var h = Math.sqrt(((x2-x1)*(x2-x1))+((y2-y1)*(y2-y1)));
  var rad = (y2-y1)/h;
  var angle = toDegrees(Math.asin(rad));
  line.style.top = y1 + 'px';
  line.style.left = x1 + 'px';
  line.style.width = h + 'px';
  line.style.transform='rotate(' + angle + 'deg)';
  return line;
}

window.drawLine = function(x1, y1, x2, y2)
{
    var l = drawLine(x1, y1, x2, y2);
    graph.appendChild(l);
};
  
function toRadians (angle)
{
  return angle * (Math.PI / 180);
}
function toDegrees(angle)
{
  return angle * (180/Math.PI);
}


    function render()
    {

        elem.appendChild(graph);

        var i = 0, len = vertices.length;
        for (i = 0; i < len; i++)
        {
            graph.appendChild(vertices[i].draw());
        }

        var len2 = edges.length;
        for (i = 0; i < len2; i++)
        {
            graph.appendChild(edges[i].draw());
        }

    }
    this.render = render;



}